import React, { Component } from 'react';
import { browserHistory, Link } from 'react-router';
import { connect } from 'react-redux';

import CKEditor from '@ckeditor/ckeditor5-react';
import ClassicEditor from '@ckeditor/ckeditor5-build-classic';

class CategoryAdd extends Component {
  constructor(props){
    super(props);
    this.state = {
      category: {
        title: '',
        description: '',
        parentId: '',
        status: 1,
        slug: '',
        feature: '',
        thumb: '',
      },
      categories: []
    };

  }
  componentDidMount() {

    this.initCategories();
  }
  componentWillReceiveProps(props){
    if(props.userInfo && props.userInfo.role !== 'admin') {
      browserHistory.push('/');
    }
    if(props.userInfo && props.userInfo.role === 'admin'){
      this.setState({ isAdmin: true });
    }
  }
  handleChangeItem = name => event => {
    var category = Object.assign({}, this.state.category);
    category[name] = event.target.value
    this.setState({
      category: category
    });
  }
  onChangeEditor(content) {
    let categoryInfo = this.state.category;
    categoryInfo.description = content;
    this.setState({
      category: categoryInfo
    });
  }
  initCategories(){
    getCategories({ status: 1 }).then(res => {
      if(res && res.data){
        this.setState({
          categories: res.data,
        });
      }
    });
  }
  render() {
    const categories = this.state.categories.map(
      category => <option value={category._id} key={category._id}>{category.title}</option>
    );

    const category = this.state.category;
    return (
      <div className="page-wrapper">
        <div className="container">
          <div className="row">
            <div className="col-md-12">
              <div className="form-group">
                <FormattedMessage id="text_feature" />
                <img className="img-thumbnail" src={`/${category.thumb ? category.thumb : ''}`} />
                <input type="file" onChange={this.handleUploadFeature} />
              </div>
              <div className="form-group">
                <FormattedMessage id="text_title" />
                <input type="text" className="form-control" value={category.title} onChange={this.handleChangeItem('title')} />
                {this.state.warningTitle ? this.state.warningTitle : null }
              </div>
              <div className="form-group">
                <FormattedMessage id="text_description" />
                <CKEditor
                    editor={ ClassicEditor }
                    data="<p>Hello from CKEditor 5!</p>"
                    onInit={ editor => {
                        // You can store the "editor" and use when it's needed.
                        console.log( 'Editor is ready to use!', editor );
                    } }
                    onChange={ ( event, editor ) => {
                        const data = editor.getData();
                        console.log( { event, editor, data } );
                    } }
                />
              </div>
              <div className="form-group">
                <button type="button" onClick={this.handleAdd} className="btn btn-success"><FormattedMessage id="button_save" /></button>
                <Link to="admin/categories" className="btn btn-default"><FormattedMessage id="button_back" /></Link>
              </div>
            </div>
          </div>
        </div>
      </div>
    );
  }
}

// Retrieve data from store as props
function mapStateToProps(state) {
  return {
    userInfo: getUser(state),
  };
}
export default connect(mapStateToProps)(CategoryAdd);
